pub enum PrefetchLocality {
NonTemporal,
Low,
Medium,
High,
}Expand description
Prefetch locality hint levels.
These correspond to the x86 prefetch instruction locality hints. Higher locality means the data is expected to be accessed more times and should be kept in closer cache levels.
Variants
NonTemporal
Non-temporal: Data will be accessed once and then not reused. Minimizes cache pollution.
Low
Low locality: Data will be accessed a few times. Kept in L3 cache.
Medium
Medium locality: Data will be accessed several times. Kept in L2 cache.
High
High locality: Data will be accessed many times. Kept in L1 cache.